@@ -197,38 +197,29 @@ func (client *libvirtClient) CreateDomain(input CreateDomainInput) error {
 	if err != nil {
 		return fmt.Errorf("Error retrieving host architecture: %s", err)
 	}
-	// Both "s390" and "s390x" are linux kernel architectures for Linux on IBM z Systems, and they are for 31-bit and 64-bit respectively.
-	if arch == "s390x" || arch == "s390" {
-		if input.Ignition != nil {
-			if err := setIgnitionForS390X(&domainDef, client, input.Ignition, input.KubeClient, input.MachineNamespace, input.IgnitionVolumeName); err != nil {
-				return err
-			}
+	if input.Ignition != nil {
+		if err := setIgnition(&domainDef, client, input.Ignition, input.KubeClient, input.MachineNamespace, input.IgnitionVolumeName, arch); err != nil {
+			return err
+		}
+	} else if input.IgnKey != "" {
+		ignVolume, err := client.getVolume(input.IgnKey)
+		if err != nil {
+			return fmt.Errorf("error getting ignition volume: %v", err)
+		}
+		ignVolumePath, err := ignVolume.GetPath()
+		if err != nil {
+			return fmt.Errorf("error getting ignition volume path: %v", err)
+		}
+
+		if err := setCoreOSIgnition(&domainDef, ignVolumePath, arch); err != nil {
+			return err
+		}
+	} else if input.CloudInit != nil {
+		if err := setCloudInit(&domainDef, client, input.CloudInit, input.KubeClient, input.MachineNamespace, input.CloudInitVolumeName, input.DomainName); err != nil {
+			return err
 		}
 	} else {
-		if input.Ignition != nil {
-			if err := setIgnition(&domainDef, client, input.Ignition, input.KubeClient, input.MachineNamespace, input.IgnitionVolumeName); err != nil {
-				return err
-			}
-		} else if input.IgnKey != "" {
-			ignVolume, err := client.getVolume(input.IgnKey)
-			if err != nil {
-				return fmt.Errorf("error getting ignition volume: %v", err)
-			}
-			ignVolumePath, err := ignVolume.GetPath()
-			if err != nil {
-				return fmt.Errorf("error getting ignition volume path: %v", err)
-			}
-
-			if err := setCoreOSIgnition(&domainDef, ignVolumePath); err != nil {
-				return err
-			}
-		} else if input.CloudInit != nil {
-			if err := setCloudInit(&domainDef, client, input.CloudInit, input.KubeClient, input.MachineNamespace, input.CloudInitVolumeName, input.DomainName); err != nil {
-				return err
-			}
-		} else {
-			return fmt.Errorf("machine does not has a IgnKey nor CloudInit value")
-		}
+		return fmt.Errorf("machine does not has a IgnKey nor CloudInit value")
 	}
 
 	glog.Info("Set up network interface")
